@@ -12,7 +12,7 @@ Helper for using the `Mini Color TFT with Joystick FeatherWing
 * Author(s): Melissa LeBlanc-Williams
 """
 
-__version__ = "1.14.10"
+__version__ = "1.14.11"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_FeatherWing.git"
 
 from collections import namedtuple
@@ -63,8 +63,8 @@ class MiniTFTFeatherWing:
         address: int = 0x5E,
         i2c: Optional[I2C] = None,
         spi: Optional[SPI] = None,
-        cs: Optional[Pin] = None,
-        dc: Optional[Pin] = None,
+        cs: Optional[Pin] = None,  # pylint: disable=invalid-name
+        dc: Optional[Pin] = None,  # pylint: disable=invalid-name
     ):
         displayio.release_displays()
         if i2c is None:
